diff --git a/src/etc/inc/config.lib.inc b/src/etc/inc/config.lib.inc
index f98b8369821523d33c361aa12a9f1bb5970f0a56..8d1452c7edaade81c7578d51ecb50637b88a0fa9 100644
--- a/src/etc/inc/config.lib.inc
+++ b/src/etc/inc/config.lib.inc
@@ -696,6 +696,8 @@ function write_config($desc="Unknown", $backup = true, $write_config_only = fals
 		log_error(gettext('Configuration Change') . ': ' . config_get_path('revision/description'));
 	}
 
+	cleanup_backupcache();
+
 	/* re-read configuration */
 	/* NOTE: We assume that the file can be parsed since we wrote it. */
 	config_read_file(true);
@@ -917,6 +919,14 @@ function config_validate($conffile) {
 	return true;
 }
 
+/**
+ * Trim the number of cached configuration backups.
+ */
+function cleanup_backupcache() {
+	$config_history = pfSenseConfigHistory::open();
+	$config_history->syncBackupCache();
+}
+
 function backup_config(): bool
 {
 	$backup_dir = g_get('cf_conf_path') . '/backup';
@@ -1277,7 +1287,7 @@ final class pfSenseConfigHistory extends Singleton
 	 *
 	 * @return array|false
 	 */
-	private function syncBackupCache(bool $drop = false): array|false
+	public function syncBackupCache(bool $drop = false): array|false
 	{
 		/* xxh3 is the fastest */
 		$hash_algo = 'xxh3';
diff --git a/src/etc/rc.bootup b/src/etc/rc.bootup
index 23d840ef29434be43890c5c6205550391c77e3cd..bacf227effb20e6e827ad7f2f15f68f369b2456d 100755
--- a/src/etc/rc.bootup
+++ b/src/etc/rc.bootup
@@ -200,6 +200,10 @@ while (is_interface_mismatch() == true) {
 	led_kitt();
 }
 
+echo "Checking config backups consistency...";
+cleanup_backupcache();
+echo "done.\n";
+
 /* enable optional crypto modules */
 echo "Loading cryptographic accelerator drivers...";
 load_crypto();
diff --git a/src/usr/local/pfSense/include/www/backup.inc b/src/usr/local/pfSense/include/www/backup.inc
index c69fa1bf57bdd67e102233b4f6624d1e126915a3..62eb857e0b69d9487cd88a065216385c1c6494f8 100644
--- a/src/usr/local/pfSense/include/www/backup.inc
+++ b/src/usr/local/pfSense/include/www/backup.inc
@@ -461,7 +461,7 @@ function execPost($post, $postfiles, $ui = true) {
 function listBackupsJSON() {
 	global $g;
 
-	cleanup_backupcache(false);
+	cleanup_backupcache();
 
 	$raw = unserialize_data(file_get_contents(g_get('cf_conf_path') . "/backup/backup.cache"), []);
 
